@@ -25,7 +25,3 @@ class CinnamonProfile(XorgProfile):
 	@property
 	def default_greeter_type(self) -> Optional[GreeterType]:
 		return GreeterType.Lightdm
-
-	def preview_text(self) -> Optional[str]:
-		text = str(_('Environment type: {}')).format(self.profile_type.value)
-		return text + '\n' + self.packages_text()
